Crate kcr_cache_kubedl_io

Crate kcr_cache_kubedl_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cache.kubedl.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

cache.kubedl.io/v1alpha1

  • CacheBackend

Modules

v1alpha1